@@ -64,14 +64,40 @@ class FBRef:
         
         Args
         ----
-            url : str
-                The URL to get
+        url : str
+            The URL to get
         Returns
         -------
         None
         """
         self.driver.get(url)
         time.sleep(self.wait_time)
+        
+    ############################################################################
+    def requests_get(self, url):
+        """ Custom requests.get function for the FBRef module
+        
+        Calls requests.get() until the status code is 200.
+
+        Args
+        ----
+        url : Str
+            The URL to get
+        Returns
+        -------
+        None
+        """
+        got_link = False # Don't proceed until we've successfully retrieved the page
+        while not got_link:
+            response = requests.get(url)
+            time.sleep(5)
+            if response.status_code == 200:
+                # 200 - OK
+                # 403 - file not found
+                # 500 - server error
+                got_link = True
+        return response
+        
 
     ################################################################################
     def get_season_link(self, year, league):
@@ -1250,15 +1276,7 @@ class FBRef:
             available (e.g. formations, lineups, scores, player stats, etc.).\
             The fields that are available vary by competition and year.
         """
-        got_link = False # Don't proceed until we've successfully retrieved the page
-        while not got_link:
-            response = requests.get(link)
-            time.sleep(5)
-            if response.status_code == 200:
-                # 200 - OK
-                # 403 - file not found
-                # 500 - server error
-                got_link = True
+        response = self.requests_get(link)
         soup = BeautifulSoup(response.content, 'html.parser')
         
         #### Matchweek ####
@@ -1289,6 +1307,9 @@ class FBRef:
         home_team_id   = team_els[0]['href'].split('/')[3]
         away_team_name = team_els[1].getText()
         away_team_id   = team_els[1]['href'].split('/')[3]
+        
+        #### Scores ####
+        scores = soup.find('div', {'class': 'scorebox'}).find_all('div', {'class': 'score'})
 
         #### Formations ####
         lineups = [pd.read_html(str(el.find('table')))[0] \
@@ -1374,8 +1395,8 @@ class FBRef:
             lineups[1].columns[0].split('(')[-1].replace(')','').strip() 
             if len(lineups)>0 else None
         )
-        match['Home Goals'] = player_stats['Home']['Summary'][('Performance','Gls')].values[-1]
-        match['Away Goals'] = player_stats['Away']['Summary'][('Performance','Gls')].values[-1]
+        match['Home Goals'] = int(scores[0].getText())
+        match['Away Goals'] = int(scores[1].getText())
         match['Home Ast'] = player_stats['Home']['Summary'][('Performance','Ast')].values[-1]
         match['Away Ast'] = player_stats['Away']['Summary'][('Performance','Ast')].values[-1]
         match['Home xG']   = (
